![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nepox)
[![PyPI](https://img.shields.io/pypi/v/nepox?color=red)](https://pypi.org/project/nepox/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![GitHub](https://img.shields.io/github/license/mortafix/nepox)

# Setup
You can find the package, [here](https://pypi.org/project/nepox/).
```
pip3 install nepox
```

# Usage
You can use the help (`-h`) for more information.
```bash
nepox project-name # simple
nepox project-name -e sublime # with editor specification
```